{
    "$graph": [
        {
            "class": "CommandLineTool",
            "baseCommand": "Rscript",
            "requirements": [
                {
                    "dockerPull": "filipejesus/dexseq:3.8",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "counts_matrix": {
                        "type": "Directory",
                        "inputBinding": {
                            "position": 2,
                            "prefix": "--count_matrix_dir"
                        }
                    },
                    "id": "#dexseq.cwl/input_script"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--metadata"
                    },
                    "id": "#dexseq.cwl/metadata"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--threads"
                    },
                    "id": "#dexseq.cwl/threads"
                }
            ],
            "id": "#dexseq.cwl",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.csv"
                    },
                    "id": "#dexseq.cwl/dexseq_out"
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "Any",
                    "id": "#folder.cwl/item"
                },
                {
                    "type": "string",
                    "id": "#folder.cwl/name"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "id": "#folder.cwl/out"
                }
            ],
            "expression": "${ if (inputs.item.class == 'Directory'){ return { 'out': { 'class': 'Directory', 'basename': inputs.name, 'listing': [inputs.item] } } }; if (inputs.item.class == 'File'){ var arr = [inputs.item]; } else { var arr = inputs.item; } return { 'out': { 'class': 'Directory', 'basename': inputs.name, 'listing': arr } } }",
            "id": "#folder.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": null,
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/hisat2:2.1.0--py27h2d50403_2",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "arguments": [
                {
                    "position": 1,
                    "valueFrom": "mkdir"
                },
                {
                    "position": 2,
                    "valueFrom": "$(inputs.output.split('.')[0])"
                },
                {
                    "position": 3,
                    "shellQuote": false,
                    "valueFrom": "&& cd"
                },
                {
                    "position": 4,
                    "valueFrom": "$(inputs.output.split('.')[0])"
                },
                {
                    "position": 5,
                    "shellQuote": false,
                    "valueFrom": "&& hisat2"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "--dta-cufflinks",
                    "inputBinding": {
                        "position": 14
                    },
                    "id": "#hisat2_align.cwl/XSTag"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-1"
                    },
                    "id": "#hisat2_align.cwl/first_pair"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-x",
                        "valueFrom": "${return inputs.index_directory.path + '/' + inputs.index_directory.listing[0].nameroot.split('.').slice(0,-1).join('.')}"
                    },
                    "id": "#hisat2_align.cwl/index_directory"
                },
                {
                    "type": "string",
                    "default": "-q",
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#hisat2_align.cwl/input_type"
                },
                {
                    "type": "string",
                    "default": "log.txt",
                    "inputBinding": {
                        "position": 15,
                        "prefix": "--summary-file"
                    },
                    "id": "#hisat2_align.cwl/log"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-S"
                    },
                    "id": "#hisat2_align.cwl/output"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-2"
                    },
                    "id": "#hisat2_align.cwl/second_pair"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-U"
                    },
                    "id": "#hisat2_align.cwl/single_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "--sra-acc"
                    },
                    "id": "#hisat2_align.cwl/sra_acc"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 13,
                        "prefix": "-p"
                    },
                    "id": "#hisat2_align.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.output.split('.')[0])"
                    },
                    "id": "#hisat2_align.cwl/hisat2_align_out"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output.split('.')[0] + '/' + inputs.output)"
                    },
                    "id": "#hisat2_align.cwl/sam_output"
                }
            ],
            "id": "#hisat2_align.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "python",
            "requirements": [
                {
                    "dockerPull": "genomicpariscentre/htseq:0.11.0",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#htseq_count.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#htseq_count.cwl/gff"
                },
                {
                    "type": "string",
                    "default": "bam",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-f"
                    },
                    "id": "#htseq_count.cwl/input_format"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#htseq_count.cwl/input_script"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#htseq_count.cwl/outname"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-p"
                    },
                    "id": "#htseq_count.cwl/pairedend"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-r"
                    },
                    "id": "#htseq_count.cwl/sorted_by"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-s"
                    },
                    "id": "#htseq_count.cwl/stranded"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#htseq_count.cwl/exon_count_output"
                }
            ],
            "id": "#htseq_count.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "python",
            "requirements": [
                {
                    "dockerPull": "genomicpariscentre/htseq",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#htseq_prepare.cwl/gff_name"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#htseq_prepare.cwl/gtf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#htseq_prepare.cwl/input_script"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#htseq_prepare.cwl/ht_prep_out"
                }
            ],
            "id": "#htseq_prepare.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "samtools",
            "requirements": [
                {
                    "dockerPull": "genomicpariscentre/samtools",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": "sort",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#samtools.cwl/action"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-o",
                        "position": 4
                    },
                    "id": "#samtools.cwl/outfilename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#samtools.cwl/samfile"
                },
                {
                    "type": "string",
                    "default": null,
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#samtools.cwl/sortby"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "-@",
                        "position": 3
                    },
                    "id": "#samtools.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outfilename)"
                    },
                    "id": "#samtools.cwl/samtools_out"
                }
            ],
            "id": "#samtools.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/annotation"
                },
                {
                    "type": "File",
                    "id": "#main/dexseq_script"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/fastq1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/fastq2"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/fastq3"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/fastq4"
                },
                {
                    "type": "Directory",
                    "id": "#main/genomeDir"
                },
                {
                    "type": "File",
                    "id": "#main/htseq_count_script"
                },
                {
                    "type": "File",
                    "id": "#main/htseq_prepare_script"
                },
                {
                    "type": "File",
                    "id": "#main/metadata"
                },
                {
                    "type": "string",
                    "id": "#main/subject_name1"
                },
                {
                    "type": "string",
                    "id": "#main/subject_name2"
                },
                {
                    "type": "string",
                    "id": "#main/subject_name3"
                },
                {
                    "type": "string",
                    "id": "#main/subject_name4"
                },
                {
                    "type": "int",
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#main/dexseq_folder/out",
                    "id": "#main/dexseq_out"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/hisat2_align_folder/out",
                    "id": "#main/hisat2_align_out"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/htseq_count_folder/out",
                    "id": "#main/htseq_count_out"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/htseq_prepare_folder/out",
                    "id": "#main/htseq_prepare_out"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/samtools_folder/out",
                    "id": "#main/samtools_out"
                }
            ],
            "steps": [
                {
                    "run": "#dexseq.cwl",
                    "in": [
                        {
                            "source": "#main/htseq_count_folder/out",
                            "id": "#main/dexseq/counts_matrix"
                        },
                        {
                            "source": "#main/htseq_prepare_folder/out",
                            "id": "#main/dexseq/gff"
                        },
                        {
                            "source": "#main/dexseq_script",
                            "id": "#main/dexseq/input_script"
                        },
                        {
                            "source": "#main/metadata",
                            "id": "#main/dexseq/metadata"
                        }
                    ],
                    "out": [
                        "#main/dexseq/dexseq_out"
                    ],
                    "id": "#main/dexseq"
                },
                {
                    "run": "#folder.cwl",
                    "in": [
                        {
                            "source": "#main/dexseq/dexseq_out",
                            "id": "#main/dexseq_folder/item"
                        },
                        {
                            "valueFrom": "DEXSeq",
                            "id": "#main/dexseq_folder/name"
                        }
                    ],
                    "out": [
                        "#main/dexseq_folder/out"
                    ],
                    "id": "#main/dexseq_folder"
                },
                {
                    "run": "#hisat2_align.cwl",
                    "in": [
                        {
                            "source": "#main/fastq1",
                            "valueFrom": "$(self[0])",
                            "id": "#main/hisat2_align_1/first_pair"
                        },
                        {
                            "source": "#main/genomeDir",
                            "id": "#main/hisat2_align_1/index_directory"
                        },
                        {
                            "source": "#main/subject_name1",
                            "valueFrom": "$(self + '.sam')",
                            "id": "#main/hisat2_align_1/output"
                        },
                        {
                            "source": "#main/fastq1",
                            "valueFrom": "$(self[1])",
                            "id": "#main/hisat2_align_1/second_pair"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/hisat2_align_1/threads"
                        }
                    ],
                    "out": [
                        "#main/hisat2_align_1/sam_output",
                        "#main/hisat2_align_1/hisat2_align_out"
                    ],
                    "id": "#main/hisat2_align_1"
                },
                {
                    "run": "#hisat2_align.cwl",
                    "in": [
                        {
                            "source": "#main/fastq2",
                            "valueFrom": "$(self[0])",
                            "id": "#main/hisat2_align_2/first_pair"
                        },
                        {
                            "source": "#main/genomeDir",
                            "id": "#main/hisat2_align_2/index_directory"
                        },
                        {
                            "source": "#main/subject_name2",
                            "valueFrom": "$(self + '.sam')",
                            "id": "#main/hisat2_align_2/output"
                        },
                        {
                            "source": "#main/fastq2",
                            "valueFrom": "$(self[1])",
                            "id": "#main/hisat2_align_2/second_pair"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/hisat2_align_2/threads"
                        }
                    ],
                    "out": [
                        "#main/hisat2_align_2/sam_output",
                        "#main/hisat2_align_2/hisat2_align_out"
                    ],
                    "id": "#main/hisat2_align_2"
                },
                {
                    "run": "#hisat2_align.cwl",
                    "in": [
                        {
                            "source": "#main/genomeDir",
                            "id": "#main/hisat2_align_3/index_directory"
                        },
                        {
                            "source": "#main/subject_name3",
                            "valueFrom": "$(self + '.sam')",
                            "id": "#main/hisat2_align_3/output"
                        },
                        {
                            "source": "#main/fastq3",
                            "id": "#main/hisat2_align_3/single_file"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/hisat2_align_3/threads"
                        }
                    ],
                    "out": [
                        "#main/hisat2_align_3/sam_output",
                        "#main/hisat2_align_3/hisat2_align_out"
                    ],
                    "id": "#main/hisat2_align_3"
                },
                {
                    "run": "#hisat2_align.cwl",
                    "in": [
                        {
                            "source": "#main/genomeDir",
                            "id": "#main/hisat2_align_4/index_directory"
                        },
                        {
                            "source": "#main/subject_name4",
                            "valueFrom": "$(self + '.sam')",
                            "id": "#main/hisat2_align_4/output"
                        },
                        {
                            "source": "#main/fastq4",
                            "id": "#main/hisat2_align_4/single_file"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/hisat2_align_4/threads"
                        }
                    ],
                    "out": [
                        "#main/hisat2_align_4/sam_output",
                        "#main/hisat2_align_4/hisat2_align_out"
                    ],
                    "id": "#main/hisat2_align_4"
                },
                {
                    "run": "#folder.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/hisat2_align_1/hisat2_align_out",
                                "#main/hisat2_align_2/hisat2_align_out",
                                "#main/hisat2_align_3/hisat2_align_out",
                                "#main/hisat2_align_4/hisat2_align_out"
                            ],
                            "id": "#main/hisat2_align_folder/item"
                        },
                        {
                            "valueFrom": "hisat2",
                            "id": "#main/hisat2_align_folder/name"
                        }
                    ],
                    "out": [
                        "#main/hisat2_align_folder/out"
                    ],
                    "id": "#main/hisat2_align_folder"
                },
                {
                    "run": "#htseq_count.cwl",
                    "in": [
                        {
                            "source": "#main/samtools_1/samtools_out",
                            "id": "#main/htseq_count_1/bam"
                        },
                        {
                            "source": "#main/htseq_prepare/ht_prep_out",
                            "id": "#main/htseq_count_1/gff"
                        },
                        {
                            "valueFrom": "bam",
                            "id": "#main/htseq_count_1/input_format"
                        },
                        {
                            "source": "#main/htseq_count_script",
                            "id": "#main/htseq_count_1/input_script"
                        },
                        {
                            "source": [
                                "#main/subject_name1"
                            ],
                            "valueFrom": "$(self + '_htseq_count.csv')",
                            "id": "#main/htseq_count_1/outname"
                        },
                        {
                            "valueFrom": "yes",
                            "id": "#main/htseq_count_1/pairedend"
                        },
                        {
                            "valueFrom": "pos",
                            "id": "#main/htseq_count_1/sorted_by"
                        },
                        {
                            "valueFrom": "no",
                            "id": "#main/htseq_count_1/stranded"
                        }
                    ],
                    "out": [
                        "#main/htseq_count_1/exon_count_output"
                    ],
                    "id": "#main/htseq_count_1"
                },
                {
                    "run": "#htseq_count.cwl",
                    "in": [
                        {
                            "source": "#main/samtools_2/samtools_out",
                            "id": "#main/htseq_count_2/bam"
                        },
                        {
                            "source": "#main/htseq_prepare/ht_prep_out",
                            "id": "#main/htseq_count_2/gff"
                        },
                        {
                            "valueFrom": "bam",
                            "id": "#main/htseq_count_2/input_format"
                        },
                        {
                            "source": "#main/htseq_count_script",
                            "id": "#main/htseq_count_2/input_script"
                        },
                        {
                            "source": [
                                "#main/subject_name2"
                            ],
                            "valueFrom": "$(self + '_htseq_count.csv')",
                            "id": "#main/htseq_count_2/outname"
                        },
                        {
                            "valueFrom": "yes",
                            "id": "#main/htseq_count_2/pairedend"
                        },
                        {
                            "valueFrom": "pos",
                            "id": "#main/htseq_count_2/sorted_by"
                        },
                        {
                            "valueFrom": "no",
                            "id": "#main/htseq_count_2/stranded"
                        }
                    ],
                    "out": [
                        "#main/htseq_count_2/exon_count_output"
                    ],
                    "id": "#main/htseq_count_2"
                },
                {
                    "run": "#htseq_count.cwl",
                    "in": [
                        {
                            "source": "#main/samtools_3/samtools_out",
                            "id": "#main/htseq_count_3/bam"
                        },
                        {
                            "source": "#main/htseq_prepare/ht_prep_out",
                            "id": "#main/htseq_count_3/gff"
                        },
                        {
                            "valueFrom": "bam",
                            "id": "#main/htseq_count_3/input_format"
                        },
                        {
                            "source": "#main/htseq_count_script",
                            "id": "#main/htseq_count_3/input_script"
                        },
                        {
                            "source": [
                                "#main/subject_name3"
                            ],
                            "valueFrom": "$(self + '_htseq_count.csv')",
                            "id": "#main/htseq_count_3/outname"
                        },
                        {
                            "valueFrom": "no",
                            "id": "#main/htseq_count_3/pairedend"
                        },
                        {
                            "valueFrom": "pos",
                            "id": "#main/htseq_count_3/sorted_by"
                        },
                        {
                            "valueFrom": "no",
                            "id": "#main/htseq_count_3/stranded"
                        }
                    ],
                    "out": [
                        "#main/htseq_count_3/exon_count_output"
                    ],
                    "id": "#main/htseq_count_3"
                },
                {
                    "run": "#htseq_count.cwl",
                    "in": [
                        {
                            "source": "#main/samtools_4/samtools_out",
                            "id": "#main/htseq_count_4/bam"
                        },
                        {
                            "source": "#main/htseq_prepare/ht_prep_out",
                            "id": "#main/htseq_count_4/gff"
                        },
                        {
                            "valueFrom": "bam",
                            "id": "#main/htseq_count_4/input_format"
                        },
                        {
                            "source": "#main/htseq_count_script",
                            "id": "#main/htseq_count_4/input_script"
                        },
                        {
                            "source": [
                                "#main/subject_name4"
                            ],
                            "valueFrom": "$(self + '_htseq_count.csv')",
                            "id": "#main/htseq_count_4/outname"
                        },
                        {
                            "valueFrom": "no",
                            "id": "#main/htseq_count_4/pairedend"
                        },
                        {
                            "valueFrom": "pos",
                            "id": "#main/htseq_count_4/sorted_by"
                        },
                        {
                            "valueFrom": "no",
                            "id": "#main/htseq_count_4/stranded"
                        }
                    ],
                    "out": [
                        "#main/htseq_count_4/exon_count_output"
                    ],
                    "id": "#main/htseq_count_4"
                },
                {
                    "run": "#folder.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/htseq_count_1/exon_count_output",
                                "#main/htseq_count_2/exon_count_output",
                                "#main/htseq_count_3/exon_count_output",
                                "#main/htseq_count_4/exon_count_output"
                            ],
                            "id": "#main/htseq_count_folder/item"
                        },
                        {
                            "valueFrom": "htseq_count",
                            "id": "#main/htseq_count_folder/name"
                        }
                    ],
                    "out": [
                        "#main/htseq_count_folder/out"
                    ],
                    "id": "#main/htseq_count_folder"
                },
                {
                    "run": "#htseq_prepare.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/annotation"
                            ],
                            "valueFrom": "$(self.nameroot + '.gff')",
                            "id": "#main/htseq_prepare/gff_name"
                        },
                        {
                            "source": "#main/annotation",
                            "id": "#main/htseq_prepare/gtf"
                        },
                        {
                            "source": "#main/htseq_prepare_script",
                            "id": "#main/htseq_prepare/input_script"
                        }
                    ],
                    "out": [
                        "#main/htseq_prepare/ht_prep_out"
                    ],
                    "id": "#main/htseq_prepare"
                },
                {
                    "run": "#folder.cwl",
                    "in": [
                        {
                            "source": "#main/htseq_prepare/ht_prep_out",
                            "id": "#main/htseq_prepare_folder/item"
                        },
                        {
                            "valueFrom": "htseq_prepare",
                            "id": "#main/htseq_prepare_folder/name"
                        }
                    ],
                    "out": [
                        "#main/htseq_prepare_folder/out"
                    ],
                    "id": "#main/htseq_prepare_folder"
                },
                {
                    "run": "#samtools.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/subject_name1"
                            ],
                            "valueFrom": "$(self + '.bam')",
                            "id": "#main/samtools_1/outfilename"
                        },
                        {
                            "source": "#main/hisat2_align_1/sam_output",
                            "id": "#main/samtools_1/samfile"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/samtools_1/threads"
                        }
                    ],
                    "out": [
                        "#main/samtools_1/samtools_out"
                    ],
                    "id": "#main/samtools_1"
                },
                {
                    "run": "#samtools.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/subject_name2"
                            ],
                            "valueFrom": "$(self + '.bam')",
                            "id": "#main/samtools_2/outfilename"
                        },
                        {
                            "source": "#main/hisat2_align_2/sam_output",
                            "id": "#main/samtools_2/samfile"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/samtools_2/threads"
                        }
                    ],
                    "out": [
                        "#main/samtools_2/samtools_out"
                    ],
                    "id": "#main/samtools_2"
                },
                {
                    "run": "#samtools.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/subject_name3"
                            ],
                            "valueFrom": "$(self + '.bam')",
                            "id": "#main/samtools_3/outfilename"
                        },
                        {
                            "source": "#main/hisat2_align_3/sam_output",
                            "id": "#main/samtools_3/samfile"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/samtools_3/threads"
                        }
                    ],
                    "out": [
                        "#main/samtools_3/samtools_out"
                    ],
                    "id": "#main/samtools_3"
                },
                {
                    "run": "#samtools.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/subject_name4"
                            ],
                            "valueFrom": "$(self + '.bam')",
                            "id": "#main/samtools_4/outfilename"
                        },
                        {
                            "source": "#main/hisat2_align_4/sam_output",
                            "id": "#main/samtools_4/samfile"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/samtools_4/threads"
                        }
                    ],
                    "out": [
                        "#main/samtools_4/samtools_out"
                    ],
                    "id": "#main/samtools_4"
                },
                {
                    "run": "#folder.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/samtools_1/samtools_out",
                                "#main/samtools_2/samtools_out",
                                "#main/samtools_3/samtools_out",
                                "#main/samtools_4/samtools_out"
                            ],
                            "id": "#main/samtools_folder/item"
                        },
                        {
                            "valueFrom": "samtools",
                            "id": "#main/samtools_folder/name"
                        }
                    ],
                    "out": [
                        "#main/samtools_folder/out"
                    ],
                    "id": "#main/samtools_folder"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
